@@ -1,7 +1,7 @@
 //
 // ned, https://github.com/nevdelap/ned, tests/matches.rs
 //
-// Copyright 2016-2021 Nev Delap (nevdelap at gmail)
+// Copyright 2016-2024 Nev Delap (nevdelap at gmail)
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -1687,7 +1687,7 @@ fn really_test(
         .map(|arg| arg.to_string())
         .collect::<Vec<String>>();
     args.insert(0, pattern.to_string());
-    env::set_var("NED_DEFAULTS", "");
+    unsafe { env::set_var("NED_DEFAULTS", "") };
     let options_with_defaults = OptionsWithDefaults::new(make_opts(), &args).unwrap();
     let parameters = get_parameters(&options_with_defaults).unwrap();
 
